@@ -24,6 +24,7 @@ class QueryableMixin(object):
     _prevent_primary_key_initialization_ = True
     _prevent_primary_key_updation_ = True
     _fields_forbidden_from_being_set_ = None
+    allow_updation_based_on_unique_keys = False
 
     @classmethod
     def is_a_to_many_rel(cls, attr):
@@ -174,9 +175,11 @@ class QueryableMixin(object):
             **kwargs: a dictionary of parameters
         """
         # kwargs.pop('csrf_token', None)
+        attrs_to_delete = []
         for attr, val in kwargs.items():
             if cls.is_the_primary_key(attr) and cls._prevent_primary_key_initialization_:
-                del kwargs[attr]
+                attrs_to_delete.append(attr)
+                # del kwargs[attr]
                 continue
             if val == "":
                 # Making an assumption that there is no good usecase
@@ -192,17 +195,29 @@ class QueryableMixin(object):
                         if all(isinstance(v, dict) for v in val):
                             rel_cls = cls.mapped_rel_class(attr)
                             kwargs[attr] = rel_cls.update_or_new_all(
-                                list_of_kwargs=val)
+                                list_of_kwargs=val,
+                                keys=None if rel_cls.allow_updation_based_on_unique_keys else [
+                                    rel_cls.primary_key_name()]
+                            )
                     elif isinstance(val, dict):
                         rel_cls = cls.mapped_rel_class(attr)
                         mapping_col = rel.collection_class().keyfunc.name
                         list_of_kwargs = [
                             merge(v, {mapping_col: k}) for k, v in val.items()]
-                        kwargs[attr] = {getattr(obj, mapping_col): obj for obj in rel_cls.update_or_new_all(
-                            list_of_kwargs=list_of_kwargs)}
+                        kwargs[attr] = {
+                            getattr(obj, mapping_col): obj 
+                            for obj in rel_cls.update_or_new_all(
+                            list_of_kwargs=list_of_kwargs,
+                            keys=None if rel_cls.allow_updation_based_on_unique_keys else [
+                                rel_cls.primary_key_name()]
+                            )}
                 elif isinstance(val, dict):
                     rel_cls = cls.mapped_rel_class(attr)
+                    if not rel_cls.allow_updation_based_on_unique_keys:
+                        val['keys'] = [rel_cls.primary_key_name()]
                     kwargs[attr] = rel_cls.update_or_new(**val)
+        for attr in attrs_to_delete:
+            del kwargs[attr]
         return kwargs
 
     @classmethod
